Welcome to the ARA documentation!
=================================
.. image:: _static/ara.png

Table of Contents
=================

.. toctree::
    :maxdepth: 2

    Frequently asked questions <faq>
    Installing ARA <installation>
    CLI: ara-manage <ara-manage>
    Configuring Ansible to use ARA <ansible-configuration>
    Configuring the ARA Ansible plugins <ara-plugin-configuration>
    Configuring the ARA API server <api-configuration>
    API: Authentication and security <api-security>
    API: Endpoint documentation <api-documentation>
    API: Usage with built-in clients <api-usage>
    API: Distributed sqlite backend <distributed-sqlite-backend>
    Setting playbook names and labels <playbook-names-and-labels>
    Recording arbitrary data in playbooks <ara-record>
    Querying ARA from inside playbooks <ara-api-lookup>
    Contributing to ARA <contributing>

.. toctree::
   :maxdepth: 1

    ansible-role-ara-api <ansible-role-ara-api>
    ansible-role-ara-web <ansible-role-ara-web>
